summaryrefslogtreecommitdiff
path: root/lisp/filenotify.el
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/filenotify.el')
-rw-r--r--lisp/filenotify.el8
1 files changed, 5 insertions, 3 deletions
diff --git a/lisp/filenotify.el b/lisp/filenotify.el
index 66e7fd7a315..ba76baca3b4 100644
--- a/lisp/filenotify.el
+++ b/lisp/filenotify.el
@@ -273,14 +273,16 @@ EVENT is the cadr of the event in `file-notify-handle-event'
(nth 0 entry) (file-name-nondirectory file1)))))
;;(message
;;"file-notify-callback %S %S %S %S %S"
;;(file-notify--descriptor desc file) action file file1 registered)
(if file1
(funcall
callback
- `(,(file-notify--descriptor desc file) ,action ,file ,file1))
+ `(,(file-notify--descriptor desc (car entry))
+ ,action ,file ,file1))
(funcall
callback
- `(,(file-notify--descriptor desc file) ,action ,file)))))
+ `(,(file-notify--descriptor desc (car entry)) ,action ,file)))))
;; Modify `file-notify-descriptors'.
(when stopped
@@ -273,14 +273,16 @@ EVENT is the cadr of the event in `file-notify-handle-event'
;;(message
;;"file-notify-callback %S %S %S %S %S"
- ;;(file-notify--descriptor desc file) action file file1 registered)
+ ;;(file-notify--descriptor desc (car entry))
+ ;;action file file1 registered)
(if file1
(funcall